@@ -171,8 +171,6 @@ class Client():
             if  not self.check_login():
                 Requests.log(self.id, "[Error]Login Fail")
                 next = False
-            print("Test Sleep")
-            time.sleep(100000)
             if next:
                 self.change_yt_lang()
                 self.upload()
