@@ -1,12 +1,9 @@
 import time,os
 from sreup.common import config, utils, Requests
 from sreup.ThreadMain import ThreadMain
-thread_number=3
 arr_threads=[]
-def start(root_folder,ext):
+def start(thread_number=3):
     try:
-        config.Client.EXT=ext
-        config.Client.ROOT_FOLDER=root_folder
         utils.clear_data()
         Requests.get(config.ServerAdress.REUP_SERVER + "client/start")
         for _ in range(thread_number):
