@@ -1,6 +1,6 @@
 import os
 class ServerAdress(object):
-    IP="http://167.99.74.94"
+    MAIL_SERVER = "http://178.128.211.227"
     REUP_SERVER = "http://sreup.singerchart.com/"
 class ImageResource(object):
     dir_path = os.path.dirname(os.path.realpath(__file__))
@@ -12,8 +12,8 @@ class Client(object):
     EXT=".exe"
     ROOT_FOLDER=""
 class Timeout(object):
-    CLIENT=600
-    THREAD=86400
+    CLIENT=1800
+    THREAD=90000
 class TimeSleep(object):
     NO_JOB=60
     EXCEPT=30
\ No newline at end of file
